package pg.android.activity;

import java.util.ListIterator;

import pg.android.kernel.Device;
import pg.android.kernel.DeviceContainer;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Align;
import android.view.View;

/**
 * Zeigt die von Sensoren angekommene Werte in einem Zeitlichenablauf
 *
 */
public class HistoryView extends View {
	private int nummer;

	public HistoryView(Context context, int nummer) {
		super(context);

		this.nummer = nummer;
	}
	
	@Override
	protected void onDraw(Canvas canvas) {
		Device device = DeviceContainer.get(nummer);
		
		float min = device.disp_min; //device.minValue;
		float max = device.disp_max; //device.maxValue;
		
		// Abstand vom Displayrand
		int display_min = 70;
		int display_max = canvas.getWidth() - 50;
		
		//Anzahl der Unteerteilungen
		int teil = 5;
		
		// Diagram anpassen
		if (device.bitDepth == 1){
			teil = 1;
			min = device.minValue;
			max = device.maxValue;
		}

		Paint paint = new Paint();
		paint.setColor(Color.WHITE);
		paint.setTextSize(30);		
		
		//Hintergrundfarbe bestimmen
		canvas.drawColor(Color.rgb(64, 64, 64));
		//View drehen 
		canvas.rotate(90);
		canvas.translate(0, -canvas.getWidth());

		paint.setTextAlign(Align.RIGHT);
		
		// Achse zeichnen
		canvas.drawLine(100, 0, 100, canvas.getWidth(), paint);

		//Unterteilungen zeichnen
		for (float i = 0; i <= 1; i += (1.0 / teil)) {
			float value = (1 - i) * min + i * max;
			
			value = (float) Math.round(value * 100) / 100;
			
			//value = parser
			canvas.drawText("" + value, 100, (1 - i) * display_max + i * display_min, paint);
			canvas.drawLine(100,  (1 - i) * display_max + i * display_min, 
					        700, (1 - i) * display_max + i * display_min, paint);
		}

		// Werte anzeigen
		paint.setColor(Color.GREEN);
		synchronized (device.getHistory()) {
			final ListIterator<Float> iterator = device.getHistory().listIterator(device.getHistory().size());
			int i = 0;
			
			while (iterator.hasPrevious()) {
				float value = iterator.previous();
				float alpha = (value - min) / (max - min);
				
				if (alpha == 0) {
					alpha = canvas.getWidth() - 51;
				} else {
					alpha = (1 - alpha) * (canvas.getWidth() - 50) + alpha * 50;
				}
				
				
				canvas.drawLine(100 + i, canvas.getWidth() - 50, 
						100 + i, alpha, paint);
				i++;
			}			
		}

		paint.setColor(Color.WHITE);
		paint.setTextAlign(Align.CENTER);
		canvas.drawText(getResources().getString(R.string.time), canvas.getHeight() / 2, canvas.getWidth() - 10, paint);

		super.onDraw(canvas);	
	}	
}
